# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["ThreatEventListParams", "Search"]


class ThreatEventListParams(TypedDict, total=False):
    account_id: Required[str]
    """Account ID."""

    cursor: str
    """Cursor for pagination.

    When provided, filters are embedded in the cursor so you only need to pass
    cursor and pageSize. Returned in the previous response's result_info.cursor
    field. Use cursor-based pagination for deep pagination (beyond 100,000 records)
    or for optimal performance.
    """

    dataset_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="datasetId")]
    """
    Dataset IDs to query events from (array of UUIDs), or special value 'all' or
    '\\**' to query all event datasets for the account. If not provided, uses the
    default dataset.
    """

    force_refresh: Annotated[bool, PropertyInfo(alias="forceRefresh")]

    format: Literal["json", "stix2", "taxii"]

    order: Literal["asc", "desc"]

    order_by: Annotated[str, PropertyInfo(alias="orderBy")]

    page: float
    """Page number (1-indexed) for offset-based pagination.

    Limited to offset of 100,000 records. For deep pagination, use cursor-based
    pagination instead.
    """

    page_size: Annotated[float, PropertyInfo(alias="pageSize")]
    """Number of results per page. Maximum 25,000."""

    search: Iterable[Search]


class Search(TypedDict, total=False):
    field: str
    """Event field to search on.

    Allowed: attacker, attackerCountry, category, createdAt, date, event, indicator,
    indicatorType, killChain, mitreAttack, tags, targetCountry, targetIndustry, tlp,
    uuid.
    """

    op: Literal["equals", "not", "gt", "gte", "lt", "lte", "like", "contains", "startsWith", "endsWith", "in", "find"]
    """Search operator.

    Use 'in' for bulk lookup of up to 100 values at once, e.g. {field:'tags',
    op:'in', value:['malware','apt']}.
    """

    value: Union[str, float, SequenceNotStr[Union[str, float]]]
    """Search value.

    String or number for most operators. Array for 'in' operator (max 100 items).
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ....._models import BaseModel

__all__ = ["AzureGroupRule", "AzureAD"]


class AzureAD(BaseModel):
    id: str
    """The ID of an Azure group."""

    identity_provider_id: str
    """The ID of your Azure identity provider."""


class AzureGroupRule(BaseModel):
    """
    Matches an Azure group.
    Requires an Azure identity provider.
    """

    azure_ad: AzureAD = FieldInfo(alias="azureAD")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["OutputOptionsParam"]


class OutputOptionsParam(TypedDict, total=False):
    """The structured replacement for `logpull_options`.

    When including this field, the `logpull_option` field will be ignored.
    """

    batch_prefix: Optional[str]
    """String to be prepended before each batch."""

    batch_suffix: Optional[str]
    """String to be appended after each batch."""

    cve_2021_44228: Annotated[Optional[bool], PropertyInfo(alias="CVE-2021-44228")]
    """
    If set to true, will cause all occurrences of `${` in the generated files to be
    replaced with `x{`.
    """

    field_delimiter: Optional[str]
    """String to join fields. This field be ignored when `record_template` is set."""

    field_names: SequenceNotStr[str]
    """List of field names to be included in the Logpush output.

    For the moment, there is no option to add all fields at once, so you must
    specify all the fields names you are interested in.
    """

    merge_subrequests: Optional[bool]
    """If set to true, subrequests will be merged into the parent request.

    Only supported for the `http_requests` dataset.
    """

    output_type: Literal["ndjson", "csv"]
    """Specifies the output type, such as `ndjson` or `csv`.

    This sets default values for the rest of the settings, depending on the chosen
    output type. Some formatting rules, like string quoting, are different between
    output types.
    """

    record_delimiter: Optional[str]
    """String to be inserted in-between the records as separator."""

    record_prefix: Optional[str]
    """String to be prepended before each record."""

    record_suffix: Optional[str]
    """String to be appended after each record."""

    record_template: Optional[str]
    """
    String to use as template for each record instead of the default json key value
    mapping. All fields used in the template must be present in `field_names` as
    well, otherwise they will end up as null. Format as a Go `text/template` without
    any standard functions, like conditionals, loops, sub-templates, etc.
    """

    sample_rate: Optional[float]
    """Floating number to specify sampling rate.

    Sampling is applied on top of filtering, and regardless of the current
    `sample_interval` of the data.
    """

    timestamp_format: Literal["unixnano", "unix", "rfc3339", "rfc3339ms", "rfc3339ns"]
    """
    String to specify the format for timestamps, such as `unixnano`, `unix`,
    `rfc3339`, `rfc3339ms` or `rfc3339ns`.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .script import Script as Script
from .script_delete_params import ScriptDeleteParams as ScriptDeleteParams
from .script_update_params import ScriptUpdateParams as ScriptUpdateParams
from .script_update_response import ScriptUpdateResponse as ScriptUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .location_get_params import LocationGetParams as LocationGetParams
from .location_get_response import LocationGetResponse as LocationGetResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

from ..._types import FileTypes

__all__ = ["UserSchemaCreateParams"]


class UserSchemaCreateParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier."""

    file: Required[FileTypes]
    """Schema file bytes"""

    kind: Required[Literal["openapi_v3"]]
    """Kind of schema"""

    name: str
    """Name of the schema"""

    validation_enabled: Literal["true", "false"]
    """Flag whether schema is enabled for validation."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["CacheLevel"]


class CacheLevel(BaseModel):
    id: Optional[Literal["cache_level"]] = None
    """Apply custom caching based on the option selected."""

    value: Optional[Literal["bypass", "basic", "simplified", "aggressive", "cache_everything"]] = None
    """
    - `bypass`: Cloudflare does not cache.
    - `basic`: Delivers resources from cache when there is no query string.
    - `simplified`: Delivers the same resource to everyone independent of the query
      string.
    - `aggressive`: Caches all static content that has a query string.
    - `cache_everything`: Treats all content as static and caches all file types
      beyond the
      [Cloudflare default cached content](https://developers.cloudflare.com/cache/concepts/default-cache-behavior/#default-cached-file-extensions).
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .event import Event as Event
from .waiting_room import WaitingRoom as WaitingRoom
from .rule_edit_params import RuleEditParams as RuleEditParams
from .additional_routes import AdditionalRoutes as AdditionalRoutes
from .cookie_attributes import CookieAttributes as CookieAttributes
from .event_edit_params import EventEditParams as EventEditParams
from .event_list_params import EventListParams as EventListParams
from .waiting_room_rule import WaitingRoomRule as WaitingRoomRule
from .rule_create_params import RuleCreateParams as RuleCreateParams
from .rule_update_params import RuleUpdateParams as RuleUpdateParams
from .event_create_params import EventCreateParams as EventCreateParams
from .event_update_params import EventUpdateParams as EventUpdateParams
from .page_preview_params import PagePreviewParams as PagePreviewParams
from .setting_edit_params import SettingEditParams as SettingEditParams
from .status_get_response import StatusGetResponse as StatusGetResponse
from .setting_get_response import SettingGetResponse as SettingGetResponse
from .event_delete_response import EventDeleteResponse as EventDeleteResponse
from .page_preview_response import PagePreviewResponse as PagePreviewResponse
from .setting_edit_response import SettingEditResponse as SettingEditResponse
from .setting_update_params import SettingUpdateParams as SettingUpdateParams
from .additional_routes_param import AdditionalRoutesParam as AdditionalRoutesParam
from .cookie_attributes_param import CookieAttributesParam as CookieAttributesParam
from .setting_update_response import SettingUpdateResponse as SettingUpdateResponse
from .waiting_room_edit_params import WaitingRoomEditParams as WaitingRoomEditParams
from .waiting_room_list_params import WaitingRoomListParams as WaitingRoomListParams
from .waiting_room_create_params import WaitingRoomCreateParams as WaitingRoomCreateParams
from .waiting_room_update_params import WaitingRoomUpdateParams as WaitingRoomUpdateParams
from .waiting_room_delete_response import WaitingRoomDeleteResponse as WaitingRoomDeleteResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["FleetStatusLiveParams"]


class FleetStatusLiveParams(TypedDict, total=False):
    account_id: Required[str]

    since_minutes: Required[float]
    """Number of minutes before current time"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import builtins
from typing import TYPE_CHECKING, Dict, List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "NamespaceChatCompletionsResponse",
    "Choice",
    "ChoiceMessage",
    "Chunk",
    "ChunkItem",
    "ChunkScoringDetails",
    "Error",
]


class ChoiceMessage(BaseModel):
    content: Optional[str] = None

    role: Literal["system", "developer", "user", "assistant", "tool"]

    if TYPE_CHECKING:
        # Some versions of Pydantic <2.8.0 have a bug and don’t allow assigning a
        # value to this field, so for compatibility we avoid doing it at runtime.
        __pydantic_extra__: Dict[str, object] = FieldInfo(init=False)  # pyright: ignore[reportIncompatibleVariableOverride]

        # Stub to indicate that arbitrary properties are accepted.
        # To access properties that are not valid identifiers you can use `getattr`, e.g.
        # `getattr(obj, '$type')`
        def __getattr__(self, attr: str) -> object: ...
    else:
        __pydantic_extra__: Dict[str, object]


class Choice(BaseModel):
    message: ChoiceMessage

    index: Optional[int] = None


class ChunkItem(BaseModel):
    key: str

    metadata: Optional[Dict[str, object]] = None

    timestamp: Optional[float] = None


class ChunkScoringDetails(BaseModel):
    fusion_method: Optional[Literal["rrf", "max"]] = None

    keyword_rank: Optional[float] = None

    keyword_score: Optional[float] = None

    reranking_score: Optional[float] = None

    vector_rank: Optional[float] = None

    vector_score: Optional[float] = None


class Chunk(BaseModel):
    id: str

    instance_id: str

    score: float

    text: str

    type: str

    item: Optional[ChunkItem] = None

    scoring_details: Optional[ChunkScoringDetails] = None


class Error(BaseModel):
    instance_id: str

    message: str


class NamespaceChatCompletionsResponse(BaseModel):
    choices: List[Choice]

    chunks: List[Chunk]

    id: Optional[str] = None

    errors: Optional[List[Error]] = None

    model: Optional[str] = None

    object: Optional[str] = None

    if TYPE_CHECKING:
        # Some versions of Pydantic <2.8.0 have a bug and don’t allow assigning a
        # value to this field, so for compatibility we avoid doing it at runtime.
        __pydantic_extra__: Dict[str, builtins.object] = FieldInfo(init=False)  # pyright: ignore[reportIncompatibleVariableOverride]

        # Stub to indicate that arbitrary properties are accepted.
        # To access properties that are not valid identifiers you can use `getattr`, e.g.
        # `getattr(obj, '$type')`
        def __getattr__(self, attr: str) -> builtins.object: ...
    else:
        __pydantic_extra__: Dict[str, builtins.object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["CNIListParams"]


class CNIListParams(TypedDict, total=False):
    account_id: Required[str]
    """Customer account tag"""

    cursor: Optional[int]

    limit: Optional[int]

    slot: Optional[str]
    """If specified, only show CNIs associated with the specified slot"""

    tunnel_id: Optional[str]
    """If specified, only show cnis associated with the specified tunnel id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["ValidationMethod"]

ValidationMethod: TypeAlias = Literal["http", "cname", "txt"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ...._base_client import make_request_options
from ....types.magic_network_monitoring.rules import advertisement_edit_params
from ....types.magic_network_monitoring.rules.advertisement import Advertisement

__all__ = ["AdvertisementsResource", "AsyncAdvertisementsResource"]


class AdvertisementsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AdvertisementsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AdvertisementsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AdvertisementsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AdvertisementsResourceWithStreamingResponse(self)

    def edit(
        self,
        rule_id: str,
        *,
        account_id: str,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[Advertisement]:
        """Update advertisement for rule.

        Args:
          rule_id: The id of the rule.

        Must be unique.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not rule_id:
            raise ValueError(f"Expected a non-empty value for `rule_id` but received {rule_id!r}")
        return self._patch(
            path_template(
                "/accounts/{account_id}/mnm/rules/{rule_id}/advertisement", account_id=account_id, rule_id=rule_id
            ),
            body=maybe_transform(body, advertisement_edit_params.AdvertisementEditParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[Advertisement]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[Advertisement]], ResultWrapper[Advertisement]),
        )


class AsyncAdvertisementsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAdvertisementsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAdvertisementsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAdvertisementsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncAdvertisementsResourceWithStreamingResponse(self)

    async def edit(
        self,
        rule_id: str,
        *,
        account_id: str,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[Advertisement]:
        """Update advertisement for rule.

        Args:
          rule_id: The id of the rule.

        Must be unique.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not rule_id:
            raise ValueError(f"Expected a non-empty value for `rule_id` but received {rule_id!r}")
        return await self._patch(
            path_template(
                "/accounts/{account_id}/mnm/rules/{rule_id}/advertisement", account_id=account_id, rule_id=rule_id
            ),
            body=await async_maybe_transform(body, advertisement_edit_params.AdvertisementEditParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[Advertisement]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[Advertisement]], ResultWrapper[Advertisement]),
        )


class AdvertisementsResourceWithRawResponse:
    def __init__(self, advertisements: AdvertisementsResource) -> None:
        self._advertisements = advertisements

        self.edit = to_raw_response_wrapper(
            advertisements.edit,
        )


class AsyncAdvertisementsResourceWithRawResponse:
    def __init__(self, advertisements: AsyncAdvertisementsResource) -> None:
        self._advertisements = advertisements

        self.edit = async_to_raw_response_wrapper(
            advertisements.edit,
        )


class AdvertisementsResourceWithStreamingResponse:
    def __init__(self, advertisements: AdvertisementsResource) -> None:
        self._advertisements = advertisements

        self.edit = to_streamed_response_wrapper(
            advertisements.edit,
        )


class AsyncAdvertisementsResourceWithStreamingResponse:
    def __init__(self, advertisements: AsyncAdvertisementsResource) -> None:
        self._advertisements = advertisements

        self.edit = async_to_streamed_response_wrapper(
            advertisements.edit,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

from ...._types import SequenceNotStr

__all__ = ["ListEditParams", "Append"]


class ListEditParams(TypedDict, total=False):
    account_id: Required[str]

    append: Iterable[Append]
    """Add items to the list."""

    remove: SequenceNotStr[str]
    """Lists of item values you want to remove."""


class Append(TypedDict, total=False):
    description: str
    """Provide the list item description (optional)."""

    value: str
    """Specify the item value."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["TSIGCreateParams"]


class TSIGCreateParams(TypedDict, total=False):
    account_id: Required[str]

    algo: Required[str]
    """TSIG algorithm."""

    name: Required[str]
    """TSIG key name."""

    secret: Required[str]
    """TSIG secret."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Required, TypedDict

__all__ = ["UploadCreateParams", "Manifest"]


class UploadCreateParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    manifest: Required[Dict[str, Manifest]]
    """A manifest ([path]: {hash, size}) map of files to upload.

    As an example, `/blog/hello-world.html` would be a valid path key.
    """


class Manifest(TypedDict, total=False):
    hash: Required[str]
    """The hash of the file."""

    size: Required[int]
    """The size of the file in bytes."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions
from typing import Type, Optional, cast

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ....pagination import SyncSinglePage, AsyncSinglePage
from ...._base_client import AsyncPaginator, make_request_options
from ....types.zero_trust.access import bookmark_create_params, bookmark_update_params
from ....types.zero_trust.access.bookmark import Bookmark
from ....types.zero_trust.access.bookmark_delete_response import BookmarkDeleteResponse

__all__ = ["BookmarksResource", "AsyncBookmarksResource"]


class BookmarksResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> BookmarksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return BookmarksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> BookmarksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return BookmarksResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    def create(
        self,
        bookmark_id: str,
        *,
        account_id: str,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[Bookmark]:
        """
        Create a new Bookmark application.

        Args:
          bookmark_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not bookmark_id:
            raise ValueError(f"Expected a non-empty value for `bookmark_id` but received {bookmark_id!r}")
        return self._post(
            path_template(
                "/accounts/{account_id}/access/bookmarks/{bookmark_id}", account_id=account_id, bookmark_id=bookmark_id
            ),
            body=maybe_transform(body, bookmark_create_params.BookmarkCreateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[Bookmark]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[Bookmark]], ResultWrapper[Bookmark]),
        )

    @typing_extensions.deprecated("deprecated")
    def update(
        self,
        bookmark_id: str,
        *,
        account_id: str,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[Bookmark]:
        """
        Updates a configured Bookmark application.

        Args:
          bookmark_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not bookmark_id:
            raise ValueError(f"Expected a non-empty value for `bookmark_id` but received {bookmark_id!r}")
        return self._put(
            path_template(
                "/accounts/{account_id}/access/bookmarks/{bookmark_id}", account_id=account_id, bookmark_id=bookmark_id
            ),
            body=maybe_transform(body, bookmark_update_params.BookmarkUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[Bookmark]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[Bookmark]], ResultWrapper[Bookmark]),
        )

    @typing_extensions.deprecated("deprecated")
    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[Bookmark]:
        """
        Lists Bookmark applications.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/access/bookmarks", account_id=account_id),
            page=SyncSinglePage[Bookmark],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=Bookmark,
        )

    @typing_extensions.deprecated("deprecated")
    def delete(
        self,
        bookmark_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[BookmarkDeleteResponse]:
        """
        Deletes a Bookmark application.

        Args:
          bookmark_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not bookmark_id:
            raise ValueError(f"Expected a non-empty value for `bookmark_id` but received {bookmark_id!r}")
        return self._delete(
            path_template(
                "/accounts/{account_id}/access/bookmarks/{bookmark_id}", account_id=account_id, bookmark_id=bookmark_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[BookmarkDeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[BookmarkDeleteResponse]], ResultWrapper[BookmarkDeleteResponse]),
        )

    @typing_extensions.deprecated("deprecated")
    def get(
        self,
        bookmark_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[Bookmark]:
        """
        Fetches a single Bookmark application.

        Args:
          bookmark_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not bookmark_id:
            raise ValueError(f"Expected a non-empty value for `bookmark_id` but received {bookmark_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/access/bookmarks/{bookmark_id}", account_id=account_id, bookmark_id=bookmark_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[Bookmark]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[Bookmark]], ResultWrapper[Bookmark]),
        )


class AsyncBookmarksResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncBookmarksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncBookmarksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncBookmarksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncBookmarksResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    async def create(
        self,
        bookmark_id: str,
        *,
        account_id: str,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[Bookmark]:
        """
        Create a new Bookmark application.

        Args:
          bookmark_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not bookmark_id:
            raise ValueError(f"Expected a non-empty value for `bookmark_id` but received {bookmark_id!r}")
        return await self._post(
            path_template(
                "/accounts/{account_id}/access/bookmarks/{bookmark_id}", account_id=account_id, bookmark_id=bookmark_id
            ),
            body=await async_maybe_transform(body, bookmark_create_params.BookmarkCreateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[Bookmark]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[Bookmark]], ResultWrapper[Bookmark]),
        )

    @typing_extensions.deprecated("deprecated")
    async def update(
        self,
        bookmark_id: str,
        *,
        account_id: str,
        body: object,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[Bookmark]:
        """
        Updates a configured Bookmark application.

        Args:
          bookmark_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not bookmark_id:
            raise ValueError(f"Expected a non-empty value for `bookmark_id` but received {bookmark_id!r}")
        return await self._put(
            path_template(
                "/accounts/{account_id}/access/bookmarks/{bookmark_id}", account_id=account_id, bookmark_id=bookmark_id
            ),
            body=await async_maybe_transform(body, bookmark_update_params.BookmarkUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[Bookmark]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[Bookmark]], ResultWrapper[Bookmark]),
        )

    @typing_extensions.deprecated("deprecated")
    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[Bookmark, AsyncSinglePage[Bookmark]]:
        """
        Lists Bookmark applications.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/access/bookmarks", account_id=account_id),
            page=AsyncSinglePage[Bookmark],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=Bookmark,
        )

    @typing_extensions.deprecated("deprecated")
    async def delete(
        self,
        bookmark_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[BookmarkDeleteResponse]:
        """
        Deletes a Bookmark application.

        Args:
          bookmark_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not bookmark_id:
            raise ValueError(f"Expected a non-empty value for `bookmark_id` but received {bookmark_id!r}")
        return await self._delete(
            path_template(
                "/accounts/{account_id}/access/bookmarks/{bookmark_id}", account_id=account_id, bookmark_id=bookmark_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[BookmarkDeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[BookmarkDeleteResponse]], ResultWrapper[BookmarkDeleteResponse]),
        )

    @typing_extensions.deprecated("deprecated")
    async def get(
        self,
        bookmark_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[Bookmark]:
        """
        Fetches a single Bookmark application.

        Args:
          bookmark_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not bookmark_id:
            raise ValueError(f"Expected a non-empty value for `bookmark_id` but received {bookmark_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/access/bookmarks/{bookmark_id}", account_id=account_id, bookmark_id=bookmark_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[Bookmark]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[Bookmark]], ResultWrapper[Bookmark]),
        )


class BookmarksResourceWithRawResponse:
    def __init__(self, bookmarks: BookmarksResource) -> None:
        self._bookmarks = bookmarks

        self.create = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                bookmarks.create,  # pyright: ignore[reportDeprecated],
            )
        )
        self.update = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                bookmarks.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                bookmarks.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                bookmarks.delete,  # pyright: ignore[reportDeprecated],
            )
        )
        self.get = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                bookmarks.get,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncBookmarksResourceWithRawResponse:
    def __init__(self, bookmarks: AsyncBookmarksResource) -> None:
        self._bookmarks = bookmarks

        self.create = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                bookmarks.create,  # pyright: ignore[reportDeprecated],
            )
        )
        self.update = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                bookmarks.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                bookmarks.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                bookmarks.delete,  # pyright: ignore[reportDeprecated],
            )
        )
        self.get = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                bookmarks.get,  # pyright: ignore[reportDeprecated],
            )
        )


class BookmarksResourceWithStreamingResponse:
    def __init__(self, bookmarks: BookmarksResource) -> None:
        self._bookmarks = bookmarks

        self.create = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                bookmarks.create,  # pyright: ignore[reportDeprecated],
            )
        )
        self.update = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                bookmarks.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                bookmarks.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                bookmarks.delete,  # pyright: ignore[reportDeprecated],
            )
        )
        self.get = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                bookmarks.get,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncBookmarksResourceWithStreamingResponse:
    def __init__(self, bookmarks: AsyncBookmarksResource) -> None:
        self._bookmarks = bookmarks

        self.create = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                bookmarks.create,  # pyright: ignore[reportDeprecated],
            )
        )
        self.update = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                bookmarks.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                bookmarks.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                bookmarks.delete,  # pyright: ignore[reportDeprecated],
            )
        )
        self.get = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                bookmarks.get,  # pyright: ignore[reportDeprecated],
            )
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .asn import (
    ASNResource,
    AsyncASNResource,
    ASNResourceWithRawResponse,
    AsyncASNResourceWithRawResponse,
    ASNResourceWithStreamingResponse,
    AsyncASNResourceWithStreamingResponse,
)
from .dns import (
    DNSResource,
    AsyncDNSResource,
    DNSResourceWithRawResponse,
    AsyncDNSResourceWithRawResponse,
    DNSResourceWithStreamingResponse,
    AsyncDNSResourceWithStreamingResponse,
)
from .ips import (
    IPsResource,
    AsyncIPsResource,
    IPsResourceWithRawResponse,
    AsyncIPsResourceWithRawResponse,
    IPsResourceWithStreamingResponse,
    AsyncIPsResourceWithStreamingResponse,
)
from .intel import (
    IntelResource,
    AsyncIntelResource,
    IntelResourceWithRawResponse,
    AsyncIntelResourceWithRawResponse,
    IntelResourceWithStreamingResponse,
    AsyncIntelResourceWithStreamingResponse,
)
from .whois import (
    WhoisResource,
    AsyncWhoisResource,
    WhoisResourceWithRawResponse,
    AsyncWhoisResourceWithRawResponse,
    WhoisResourceWithStreamingResponse,
    AsyncWhoisResourceWithStreamingResponse,
)
from .domains import (
    DomainsResource,
    AsyncDomainsResource,
    DomainsResourceWithRawResponse,
    AsyncDomainsResourceWithRawResponse,
    DomainsResourceWithStreamingResponse,
    AsyncDomainsResourceWithStreamingResponse,
)
from .sinkholes import (
    SinkholesResource,
    AsyncSinkholesResource,
    SinkholesResourceWithRawResponse,
    AsyncSinkholesResourceWithRawResponse,
    SinkholesResourceWithStreamingResponse,
    AsyncSinkholesResourceWithStreamingResponse,
)
from .domain_history import (
    DomainHistoryResource,
    AsyncDomainHistoryResource,
    DomainHistoryResourceWithRawResponse,
    AsyncDomainHistoryResourceWithRawResponse,
    DomainHistoryResourceWithStreamingResponse,
    AsyncDomainHistoryResourceWithStreamingResponse,
)
from .indicator_feeds import (
    IndicatorFeedsResource,
    AsyncIndicatorFeedsResource,
    IndicatorFeedsResourceWithRawResponse,
    AsyncIndicatorFeedsResourceWithRawResponse,
    IndicatorFeedsResourceWithStreamingResponse,
    AsyncIndicatorFeedsResourceWithStreamingResponse,
)
from .miscategorizations import (
    MiscategorizationsResource,
    AsyncMiscategorizationsResource,
    MiscategorizationsResourceWithRawResponse,
    AsyncMiscategorizationsResourceWithRawResponse,
    MiscategorizationsResourceWithStreamingResponse,
    AsyncMiscategorizationsResourceWithStreamingResponse,
)
from .attack_surface_report import (
    AttackSurfaceReportResource,
    AsyncAttackSurfaceReportResource,
    AttackSurfaceReportResourceWithRawResponse,
    AsyncAttackSurfaceReportResourceWithRawResponse,
    AttackSurfaceReportResourceWithStreamingResponse,
    AsyncAttackSurfaceReportResourceWithStreamingResponse,
)

__all__ = [
    "ASNResource",
    "AsyncASNResource",
    "ASNResourceWithRawResponse",
    "AsyncASNResourceWithRawResponse",
    "ASNResourceWithStreamingResponse",
    "AsyncASNResourceWithStreamingResponse",
    "DNSResource",
    "AsyncDNSResource",
    "DNSResourceWithRawResponse",
    "AsyncDNSResourceWithRawResponse",
    "DNSResourceWithStreamingResponse",
    "AsyncDNSResourceWithStreamingResponse",
    "DomainsResource",
    "AsyncDomainsResource",
    "DomainsResourceWithRawResponse",
    "AsyncDomainsResourceWithRawResponse",
    "DomainsResourceWithStreamingResponse",
    "AsyncDomainsResourceWithStreamingResponse",
    "DomainHistoryResource",
    "AsyncDomainHistoryResource",
    "DomainHistoryResourceWithRawResponse",
    "AsyncDomainHistoryResourceWithRawResponse",
    "DomainHistoryResourceWithStreamingResponse",
    "AsyncDomainHistoryResourceWithStreamingResponse",
    "IPsResource",
    "AsyncIPsResource",
    "IPsResourceWithRawResponse",
    "AsyncIPsResourceWithRawResponse",
    "IPsResourceWithStreamingResponse",
    "AsyncIPsResourceWithStreamingResponse",
    "MiscategorizationsResource",
    "AsyncMiscategorizationsResource",
    "MiscategorizationsResourceWithRawResponse",
    "AsyncMiscategorizationsResourceWithRawResponse",
    "MiscategorizationsResourceWithStreamingResponse",
    "AsyncMiscategorizationsResourceWithStreamingResponse",
    "WhoisResource",
    "AsyncWhoisResource",
    "WhoisResourceWithRawResponse",
    "AsyncWhoisResourceWithRawResponse",
    "WhoisResourceWithStreamingResponse",
    "AsyncWhoisResourceWithStreamingResponse",
    "IndicatorFeedsResource",
    "AsyncIndicatorFeedsResource",
    "IndicatorFeedsResourceWithRawResponse",
    "AsyncIndicatorFeedsResourceWithRawResponse",
    "IndicatorFeedsResourceWithStreamingResponse",
    "AsyncIndicatorFeedsResourceWithStreamingResponse",
    "SinkholesResource",
    "AsyncSinkholesResource",
    "SinkholesResourceWithRawResponse",
    "AsyncSinkholesResourceWithRawResponse",
    "SinkholesResourceWithStreamingResponse",
    "AsyncSinkholesResourceWithStreamingResponse",
    "AttackSurfaceReportResource",
    "AsyncAttackSurfaceReportResource",
    "AttackSurfaceReportResourceWithRawResponse",
    "AsyncAttackSurfaceReportResourceWithRawResponse",
    "AttackSurfaceReportResourceWithStreamingResponse",
    "AsyncAttackSurfaceReportResourceWithStreamingResponse",
    "IntelResource",
    "AsyncIntelResource",
    "IntelResourceWithRawResponse",
    "AsyncIntelResourceWithRawResponse",
    "IntelResourceWithStreamingResponse",
    "AsyncIntelResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .asset_list_params import AssetListParams as AssetListParams
from .asset_get_response import AssetGetResponse as AssetGetResponse
from .asset_create_params import AssetCreateParams as AssetCreateParams
from .asset_list_response import AssetListResponse as AssetListResponse
from .asset_update_params import AssetUpdateParams as AssetUpdateParams
from .asset_create_response import AssetCreateResponse as AssetCreateResponse
from .asset_update_response import AssetUpdateResponse as AssetUpdateResponse
from .custom_page_get_response import CustomPageGetResponse as CustomPageGetResponse
from .custom_page_list_response import CustomPageListResponse as CustomPageListResponse
from .custom_page_update_params import CustomPageUpdateParams as CustomPageUpdateParams
from .custom_page_update_response import CustomPageUpdateResponse as CustomPageUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .zone import (
    ZoneResource,
    AsyncZoneResource,
    ZoneResourceWithRawResponse,
    AsyncZoneResourceWithRawResponse,
    ZoneResourceWithStreamingResponse,
    AsyncZoneResourceWithStreamingResponse,
)
from .account import (
    AccountResource,
    AsyncAccountResource,
    AccountResourceWithRawResponse,
    AsyncAccountResourceWithRawResponse,
    AccountResourceWithStreamingResponse,
    AsyncAccountResourceWithStreamingResponse,
)
from .settings import (
    SettingsResource,
    AsyncSettingsResource,
    SettingsResourceWithRawResponse,
    AsyncSettingsResourceWithRawResponse,
    SettingsResourceWithStreamingResponse,
    AsyncSettingsResourceWithStreamingResponse,
)

__all__ = [
    "ZoneResource",
    "AsyncZoneResource",
    "ZoneResourceWithRawResponse",
    "AsyncZoneResourceWithRawResponse",
    "ZoneResourceWithStreamingResponse",
    "AsyncZoneResourceWithStreamingResponse",
    "AccountResource",
    "AsyncAccountResource",
    "AccountResourceWithRawResponse",
    "AsyncAccountResourceWithRawResponse",
    "AccountResourceWithStreamingResponse",
    "AsyncAccountResourceWithStreamingResponse",
    "SettingsResource",
    "AsyncSettingsResource",
    "SettingsResourceWithRawResponse",
    "AsyncSettingsResourceWithRawResponse",
    "SettingsResourceWithStreamingResponse",
    "AsyncSettingsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["UserGroupListParams"]


class UserGroupListParams(TypedDict, total=False):
    account_id: Required[str]
    """Account identifier tag."""

    id: str
    """ID of the user group to be fetched."""

    direction: Literal["asc", "desc"]
    """The sort order of returned user groups by name (ascending or descending)."""

    fuzzy_name: Annotated[str, PropertyInfo(alias="fuzzyName")]
    """A string used for searching for user groups containing that substring."""

    name: str
    """Name of the user group to be fetched."""

    page: float
    """Page number of paginated results."""

    per_page: float
    """Maximum number of results per page."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["IndexInsertResponse"]


class IndexInsertResponse(BaseModel):
    mutation_id: Optional[str] = FieldInfo(alias="mutationId", default=None)
    """
    The unique identifier for the async mutation operation containing the changeset.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["SentineloneS2sInputParam"]


class SentineloneS2sInputParam(TypedDict, total=False):
    connection_id: Required[str]
    """Posture Integration ID."""

    active_threats: float
    """The Number of active threats."""

    infected: bool
    """Whether device is infected."""

    is_active: bool
    """Whether device is active."""

    network_status: Literal["connected", "disconnected", "disconnecting", "connecting"]
    """Network status of device."""

    operational_state: Literal[
        "na",
        "partially_disabled",
        "auto_fully_disabled",
        "fully_disabled",
        "auto_partially_disabled",
        "disabled_error",
        "db_corruption",
    ]
    """Agent operational state."""

    operator: Literal["<", "<=", ">", ">=", "=="]
    """Operator."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["SippyDeleteResponse"]


class SippyDeleteResponse(BaseModel):
    enabled: Optional[Literal[False]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["Prefix"]


class Prefix(BaseModel):
    id: Optional[str] = None
    """Identifier of an IP Prefix."""

    account_id: Optional[str] = None
    """Identifier of a Cloudflare account."""

    advertised: Optional[bool] = None
    """Prefix advertisement status to the Internet.

    This field is only not 'null' if on demand is enabled.
    """

    advertised_modified_at: Optional[datetime] = None
    """Last time the advertisement status was changed.

    This field is only not 'null' if on demand is enabled.
    """

    approved: Optional[str] = None
    """Approval state of the prefix (P = pending, V = active)."""

    asn: Optional[int] = None
    """Autonomous System Number (ASN) the prefix will be advertised under."""

    cidr: Optional[str] = None
    """IP Prefix in Classless Inter-Domain Routing format."""

    created_at: Optional[datetime] = None

    delegate_loa_creation: Optional[bool] = None
    """
    Whether Cloudflare is allowed to generate the LOA document on behalf of the
    prefix owner.
    """

    description: Optional[str] = None
    """Description of the prefix."""

    irr_validation_state: Optional[str] = None
    """State of one kind of validation for an IP prefix."""

    loa_document_id: Optional[str] = None
    """Identifier for the uploaded LOA document."""

    modified_at: Optional[datetime] = None

    on_demand_enabled: Optional[bool] = None
    """
    Whether advertisement of the prefix to the Internet may be dynamically enabled
    or disabled.
    """

    on_demand_locked: Optional[bool] = None
    """
    Whether advertisement status of the prefix is locked, meaning it cannot be
    changed.
    """

    ownership_validation_state: Optional[str] = None
    """State of one kind of validation for an IP prefix."""

    ownership_validation_token: Optional[str] = None
    """Token provided to demonstrate ownership of the prefix."""

    rpki_validation_state: Optional[str] = None
    """State of one kind of validation for an IP prefix."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .assets import (
    AssetsResource,
    AsyncAssetsResource,
    AssetsResourceWithRawResponse,
    AsyncAssetsResourceWithRawResponse,
    AssetsResourceWithStreamingResponse,
    AsyncAssetsResourceWithStreamingResponse,
)
from .public import (
    PublicResource,
    AsyncPublicResource,
    PublicResourceWithRawResponse,
    AsyncPublicResourceWithRawResponse,
    PublicResourceWithStreamingResponse,
    AsyncPublicResourceWithStreamingResponse,
)
from .finetunes import (
    FinetunesResource,
    AsyncFinetunesResource,
    FinetunesResourceWithRawResponse,
    AsyncFinetunesResourceWithRawResponse,
    FinetunesResourceWithStreamingResponse,
    AsyncFinetunesResourceWithStreamingResponse,
)

__all__ = [
    "AssetsResource",
    "AsyncAssetsResource",
    "AssetsResourceWithRawResponse",
    "AsyncAssetsResourceWithRawResponse",
    "AssetsResourceWithStreamingResponse",
    "AsyncAssetsResourceWithStreamingResponse",
    "PublicResource",
    "AsyncPublicResource",
    "PublicResourceWithRawResponse",
    "AsyncPublicResourceWithRawResponse",
    "PublicResourceWithStreamingResponse",
    "AsyncPublicResourceWithStreamingResponse",
    "FinetunesResource",
    "AsyncFinetunesResource",
    "FinetunesResourceWithRawResponse",
    "AsyncFinetunesResourceWithRawResponse",
    "FinetunesResourceWithStreamingResponse",
    "AsyncFinetunesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .metadata_index_create_params import MetadataIndexCreateParams as MetadataIndexCreateParams
from .metadata_index_delete_params import MetadataIndexDeleteParams as MetadataIndexDeleteParams
from .metadata_index_list_response import MetadataIndexListResponse as MetadataIndexListResponse
from .metadata_index_create_response import MetadataIndexCreateResponse as MetadataIndexCreateResponse
from .metadata_index_delete_response import MetadataIndexDeleteResponse as MetadataIndexDeleteResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Type, cast
from typing_extensions import Literal

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ....pagination import SyncV4PagePaginationArray, AsyncV4PagePaginationArray
from ...._base_client import AsyncPaginator, make_request_options
from ....types.api_gateway.discovery import operation_list_params, operation_bulk_edit_params
from ....types.api_gateway.discovery_operation import DiscoveryOperation
from ....types.api_gateway.discovery.operation_bulk_edit_response import OperationBulkEditResponse

__all__ = ["OperationsResource", "AsyncOperationsResource"]


class OperationsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OperationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return OperationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OperationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return OperationsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        zone_id: str,
        diff: bool | Omit = omit,
        direction: Literal["asc", "desc"] | Omit = omit,
        endpoint: str | Omit = omit,
        host: SequenceNotStr[str] | Omit = omit,
        method: SequenceNotStr[str] | Omit = omit,
        order: Literal["host", "method", "endpoint", "traffic_stats.requests", "traffic_stats.last_updated"]
        | Omit = omit,
        origin: Literal["ML", "SessionIdentifier", "LabelDiscovery"] | Omit = omit,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        state: Literal["review", "saved", "ignored"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncV4PagePaginationArray[DiscoveryOperation]:
        """
        Retrieve the most up to date view of discovered operations

        Args:
          zone_id: Identifier.

          diff: When `true`, only return API Discovery results that are not saved into API
              Shield Endpoint Management

          direction: Direction to order results.

          endpoint: Filter results to only include endpoints containing this pattern.

          host: Filter results to only include the specified hosts.

          method: Filter results to only include the specified HTTP methods.

          order: Field to order by

          origin: Filter results to only include discovery results sourced from a particular
              discovery engine

              - `ML` - Discovered operations that were sourced using ML API Discovery
              - `SessionIdentifier` - Discovered operations that were sourced using Session
                Identifier API Discovery

          page: Page number of paginated results.

          per_page: Maximum number of results per page.

          state: Filter results to only include discovery results in a particular state. States
              are as follows

              - `review` - Discovered operations that are not saved into API Shield Endpoint
                Management
              - `saved` - Discovered operations that are already saved into API Shield
                Endpoint Management
              - `ignored` - Discovered operations that have been marked as ignored

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/api_gateway/discovery/operations", zone_id=zone_id),
            page=SyncV4PagePaginationArray[DiscoveryOperation],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "diff": diff,
                        "direction": direction,
                        "endpoint": endpoint,
                        "host": host,
                        "method": method,
                        "order": order,
                        "origin": origin,
                        "page": page,
                        "per_page": per_page,
                        "state": state,
                    },
                    operation_list_params.OperationListParams,
                ),
            ),
            model=DiscoveryOperation,
        )

    def bulk_edit(
        self,
        *,
        zone_id: str,
        body: Dict[str, operation_bulk_edit_params.Body],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OperationBulkEditResponse:
        """
        Update the `state` on one or more discovered operations

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._patch(
            path_template("/zones/{zone_id}/api_gateway/discovery/operations", zone_id=zone_id),
            body=maybe_transform(body, operation_bulk_edit_params.OperationBulkEditParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[OperationBulkEditResponse]._unwrapper,
            ),
            cast_to=cast(Type[OperationBulkEditResponse], ResultWrapper[OperationBulkEditResponse]),
        )


class AsyncOperationsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOperationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncOperationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOperationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncOperationsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        zone_id: str,
        diff: bool | Omit = omit,
        direction: Literal["asc", "desc"] | Omit = omit,
        endpoint: str | Omit = omit,
        host: SequenceNotStr[str] | Omit = omit,
        method: SequenceNotStr[str] | Omit = omit,
        order: Literal["host", "method", "endpoint", "traffic_stats.requests", "traffic_stats.last_updated"]
        | Omit = omit,
        origin: Literal["ML", "SessionIdentifier", "LabelDiscovery"] | Omit = omit,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        state: Literal["review", "saved", "ignored"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[DiscoveryOperation, AsyncV4PagePaginationArray[DiscoveryOperation]]:
        """
        Retrieve the most up to date view of discovered operations

        Args:
          zone_id: Identifier.

          diff: When `true`, only return API Discovery results that are not saved into API
              Shield Endpoint Management

          direction: Direction to order results.

          endpoint: Filter results to only include endpoints containing this pattern.

          host: Filter results to only include the specified hosts.

          method: Filter results to only include the specified HTTP methods.

          order: Field to order by

          origin: Filter results to only include discovery results sourced from a particular
              discovery engine

              - `ML` - Discovered operations that were sourced using ML API Discovery
              - `SessionIdentifier` - Discovered operations that were sourced using Session
                Identifier API Discovery

          page: Page number of paginated results.

          per_page: Maximum number of results per page.

          state: Filter results to only include discovery results in a particular state. States
              are as follows

              - `review` - Discovered operations that are not saved into API Shield Endpoint
                Management
              - `saved` - Discovered operations that are already saved into API Shield
                Endpoint Management
              - `ignored` - Discovered operations that have been marked as ignored

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/api_gateway/discovery/operations", zone_id=zone_id),
            page=AsyncV4PagePaginationArray[DiscoveryOperation],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "diff": diff,
                        "direction": direction,
                        "endpoint": endpoint,
                        "host": host,
                        "method": method,
                        "order": order,
                        "origin": origin,
                        "page": page,
                        "per_page": per_page,
                        "state": state,
                    },
                    operation_list_params.OperationListParams,
                ),
            ),
            model=DiscoveryOperation,
        )

    async def bulk_edit(
        self,
        *,
        zone_id: str,
        body: Dict[str, operation_bulk_edit_params.Body],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OperationBulkEditResponse:
        """
        Update the `state` on one or more discovered operations

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._patch(
            path_template("/zones/{zone_id}/api_gateway/discovery/operations", zone_id=zone_id),
            body=await async_maybe_transform(body, operation_bulk_edit_params.OperationBulkEditParams),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[OperationBulkEditResponse]._unwrapper,
            ),
            cast_to=cast(Type[OperationBulkEditResponse], ResultWrapper[OperationBulkEditResponse]),
        )


class OperationsResourceWithRawResponse:
    def __init__(self, operations: OperationsResource) -> None:
        self._operations = operations

        self.list = to_raw_response_wrapper(
            operations.list,
        )
        self.bulk_edit = to_raw_response_wrapper(
            operations.bulk_edit,
        )


class AsyncOperationsResourceWithRawResponse:
    def __init__(self, operations: AsyncOperationsResource) -> None:
        self._operations = operations

        self.list = async_to_raw_response_wrapper(
            operations.list,
        )
        self.bulk_edit = async_to_raw_response_wrapper(
            operations.bulk_edit,
        )


class OperationsResourceWithStreamingResponse:
    def __init__(self, operations: OperationsResource) -> None:
        self._operations = operations

        self.list = to_streamed_response_wrapper(
            operations.list,
        )
        self.bulk_edit = to_streamed_response_wrapper(
            operations.bulk_edit,
        )


class AsyncOperationsResourceWithStreamingResponse:
    def __init__(self, operations: AsyncOperationsResource) -> None:
        self._operations = operations

        self.list = async_to_streamed_response_wrapper(
            operations.list,
        )
        self.bulk_edit = async_to_streamed_response_wrapper(
            operations.bulk_edit,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import TypeAlias

__all__ = ["RuleDeleteResponse"]

RuleDeleteResponse: TypeAlias = Optional[bool]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import date, datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["AuditLogListParams", "Action", "Actor", "Zone"]


class AuditLogListParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier"""

    id: str
    """Finds a specific log by its ID."""

    action: Action

    actor: Actor

    before: Annotated[Union[Union[str, date], Union[str, datetime]], PropertyInfo(format="iso8601")]
    """Limits the returned results to logs older than the specified date.

    A `full-date` that conforms to RFC3339.
    """

    direction: Literal["desc", "asc"]
    """Changes the direction of the chronological sorting."""

    export: bool
    """Indicates that this request is an export of logs in CSV format."""

    hide_user_logs: bool
    """Indicates whether or not to hide user level audit logs."""

    page: float
    """Defines which page of results to return."""

    per_page: float
    """Sets the number of results to return per page."""

    since: Annotated[Union[Union[str, date], Union[str, datetime]], PropertyInfo(format="iso8601")]
    """Limits the returned results to logs newer than the specified date.

    A `full-date` that conforms to RFC3339.
    """

    zone: Zone


class Action(TypedDict, total=False):
    type: str
    """Filters by the action type."""


class Actor(TypedDict, total=False):
    email: str
    """Filters by the email address of the actor that made the change."""

    ip: str
    """
    Filters by the IP address of the request that made the change by specific IP
    address or valid CIDR Range.
    """


class Zone(TypedDict, total=False):
    name: str
    """Filters by the name of the zone associated to the change."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ...types.ssl import verification_get_params, verification_edit_params
from ..._base_client import make_request_options
from ...types.ssl.verification_get_response import VerificationGetResponse
from ...types.ssl.verification_edit_response import VerificationEditResponse

__all__ = ["VerificationResource", "AsyncVerificationResource"]


class VerificationResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VerificationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return VerificationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VerificationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return VerificationResourceWithStreamingResponse(self)

    def edit(
        self,
        certificate_pack_id: str,
        *,
        zone_id: str,
        validation_method: Literal["http", "cname", "txt", "email"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[VerificationEditResponse]:
        """Edit SSL validation method for a certificate pack.

        A PATCH request will request
        an immediate validation check on any certificate, and return the updated status.
        If a validation method is provided, the validation will be immediately attempted
        using that method.

        Args:
          zone_id: Identifier.

          certificate_pack_id: Certificate Pack UUID.

          validation_method: Desired validation method.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not certificate_pack_id:
            raise ValueError(
                f"Expected a non-empty value for `certificate_pack_id` but received {certificate_pack_id!r}"
            )
        return self._patch(
            path_template(
                "/zones/{zone_id}/ssl/verification/{certificate_pack_id}",
                zone_id=zone_id,
                certificate_pack_id=certificate_pack_id,
            ),
            body=maybe_transform(
                {"validation_method": validation_method}, verification_edit_params.VerificationEditParams
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[VerificationEditResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[VerificationEditResponse]], ResultWrapper[VerificationEditResponse]),
        )

    def get(
        self,
        *,
        zone_id: str,
        retry: Literal[True] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[VerificationGetResponse]:
        """
        Get SSL Verification Info for a Zone.

        Args:
          zone_id: Identifier.

          retry: Immediately retry SSL Verification.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get(
            path_template("/zones/{zone_id}/ssl/verification", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"retry": retry}, verification_get_params.VerificationGetParams),
                post_parser=ResultWrapper[Optional[VerificationGetResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[VerificationGetResponse]], ResultWrapper[VerificationGetResponse]),
        )


class AsyncVerificationResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVerificationResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncVerificationResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVerificationResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncVerificationResourceWithStreamingResponse(self)

    async def edit(
        self,
        certificate_pack_id: str,
        *,
        zone_id: str,
        validation_method: Literal["http", "cname", "txt", "email"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[VerificationEditResponse]:
        """Edit SSL validation method for a certificate pack.

        A PATCH request will request
        an immediate validation check on any certificate, and return the updated status.
        If a validation method is provided, the validation will be immediately attempted
        using that method.

        Args:
          zone_id: Identifier.

          certificate_pack_id: Certificate Pack UUID.

          validation_method: Desired validation method.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not certificate_pack_id:
            raise ValueError(
                f"Expected a non-empty value for `certificate_pack_id` but received {certificate_pack_id!r}"
            )
        return await self._patch(
            path_template(
                "/zones/{zone_id}/ssl/verification/{certificate_pack_id}",
                zone_id=zone_id,
                certificate_pack_id=certificate_pack_id,
            ),
            body=await async_maybe_transform(
                {"validation_method": validation_method}, verification_edit_params.VerificationEditParams
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[VerificationEditResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[VerificationEditResponse]], ResultWrapper[VerificationEditResponse]),
        )

    async def get(
        self,
        *,
        zone_id: str,
        retry: Literal[True] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[VerificationGetResponse]:
        """
        Get SSL Verification Info for a Zone.

        Args:
          zone_id: Identifier.

          retry: Immediately retry SSL Verification.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return await self._get(
            path_template("/zones/{zone_id}/ssl/verification", zone_id=zone_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"retry": retry}, verification_get_params.VerificationGetParams),
                post_parser=ResultWrapper[Optional[VerificationGetResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[VerificationGetResponse]], ResultWrapper[VerificationGetResponse]),
        )


class VerificationResourceWithRawResponse:
    def __init__(self, verification: VerificationResource) -> None:
        self._verification = verification

        self.edit = to_raw_response_wrapper(
            verification.edit,
        )
        self.get = to_raw_response_wrapper(
            verification.get,
        )


class AsyncVerificationResourceWithRawResponse:
    def __init__(self, verification: AsyncVerificationResource) -> None:
        self._verification = verification

        self.edit = async_to_raw_response_wrapper(
            verification.edit,
        )
        self.get = async_to_raw_response_wrapper(
            verification.get,
        )


class VerificationResourceWithStreamingResponse:
    def __init__(self, verification: VerificationResource) -> None:
        self._verification = verification

        self.edit = to_streamed_response_wrapper(
            verification.edit,
        )
        self.get = to_streamed_response_wrapper(
            verification.get,
        )


class AsyncVerificationResourceWithStreamingResponse:
    def __init__(self, verification: AsyncVerificationResource) -> None:
        self._verification = verification

        self.edit = async_to_streamed_response_wrapper(
            verification.edit,
        )
        self.get = async_to_streamed_response_wrapper(
            verification.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ....._models import BaseModel

__all__ = ["TargetGetResponse"]


class TargetGetResponse(BaseModel):
    id: str
    """Target ID."""

    type: str
    """Target type (page, background_page, worker, etc.)."""

    url: str
    """URL of the target."""

    description: Optional[str] = None
    """Target description."""

    devtools_frontend_url: Optional[str] = FieldInfo(alias="devtoolsFrontendUrl", default=None)
    """DevTools frontend URL."""

    title: Optional[str] = None
    """Title of the target."""

    web_socket_debugger_url: Optional[str] = FieldInfo(alias="webSocketDebuggerUrl", default=None)
    """WebSocket URL for debugging this target."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .phases import (
    PhasesResource,
    AsyncPhasesResource,
    PhasesResourceWithRawResponse,
    AsyncPhasesResourceWithRawResponse,
    PhasesResourceWithStreamingResponse,
    AsyncPhasesResourceWithStreamingResponse,
)
from .versions import (
    VersionsResource,
    AsyncVersionsResource,
    VersionsResourceWithRawResponse,
    AsyncVersionsResourceWithRawResponse,
    VersionsResourceWithStreamingResponse,
    AsyncVersionsResourceWithStreamingResponse,
)

__all__ = [
    "VersionsResource",
    "AsyncVersionsResource",
    "VersionsResourceWithRawResponse",
    "AsyncVersionsResourceWithRawResponse",
    "VersionsResourceWithStreamingResponse",
    "AsyncVersionsResourceWithStreamingResponse",
    "PhasesResource",
    "AsyncPhasesResource",
    "PhasesResourceWithRawResponse",
    "AsyncPhasesResourceWithRawResponse",
    "PhasesResourceWithStreamingResponse",
    "AsyncPhasesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["WARPEditParams"]


class WARPEditParams(TypedDict, total=False):
    account_id: Required[str]
    """Cloudflare account ID"""

    comment: str
    """An optional description of the subnet."""

    is_default_network: bool
    """If `true`, this is the default subnet for the account.

    There can only be one default subnet per account.
    """

    name: str
    """A user-friendly name for the subnet."""

    network: str
    """The private IPv4 or IPv6 range defining the subnet, in CIDR notation."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from typing_extensions import Literal, Required, TypeAlias, TypedDict

__all__ = [
    "AbuseReportCreateParams",
    "AbuseReportsDmcaReport",
    "AbuseReportsTrademarkReport",
    "AbuseReportsGeneralReport",
    "AbuseReportsPhishingReport",
    "AbuseReportsCsamReport",
    "AbuseReportsThreatReport",
    "AbuseReportsRegistrarWhoisReport",
    "AbuseReportsRegistrarWhoisReportRegWhoRequest",
    "AbuseReportsNcseiReport",
]


class AbuseReportsDmcaReport(TypedDict, total=False):
    account_id: Required[str]

    act: Required[Literal["abuse_dmca"]]
    """The report type for submitted reports."""

    address1: Required[str]
    """Text not exceeding 100 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    agent_name: Required[str]
    """The name of the copyright holder.

    Text not exceeding 60 characters. This field may be released by Cloudflare to
    third parties such as the Lumen Database (https://lumendatabase.org/).
    """

    agree: Required[Literal[1]]
    """Can be `0` for false or `1` for true. Must be value: 1 for DMCA reports"""

    city: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    country: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    email: Required[str]
    """A valid email of the abuse reporter.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    email2: Required[str]
    """Should match the value provided in `email`"""

    host_notification: Required[Literal["send"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    name: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    original_work: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    owner_notification: Required[Literal["send"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    signature: Required[str]
    """Required for DMCA reports, should be same as Name.

    An affirmation that all information in the report is true and accurate while
    agreeing to the policies of Cloudflare's abuse reports
    """

    state: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    urls: Required[str]
    """A list of valid URLs separated by ‘\n’ (new line character).

    The list of the URLs should not exceed 250 URLs. All URLs should have the same
    hostname. Each URL should be unique. This field may be released by Cloudflare to
    third parties such as the Lumen Database (https://lumendatabase.org/).
    """

    comments: str
    """Any additional comments about the infringement not exceeding 2000 characters"""

    company: str
    """Text not exceeding 100 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    reported_country: str
    """Text containing 2 characters"""

    reported_user_agent: str
    """Text not exceeding 255 characters"""

    tele: str
    """Text not exceeding 20 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    title: str
    """Text not exceeding 255 characters"""


class AbuseReportsTrademarkReport(TypedDict, total=False):
    account_id: Required[str]

    act: Required[Literal["abuse_trademark"]]
    """The report type for submitted reports."""

    email: Required[str]
    """A valid email of the abuse reporter.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    email2: Required[str]
    """Should match the value provided in `email`"""

    host_notification: Required[Literal["send"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    justification: Required[str]
    """
    A detailed description of the infringement, including any necessary access
    details and the exact steps needed to view the content, not exceeding 5000
    characters.
    """

    name: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    owner_notification: Required[Literal["send"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    trademark_number: Required[str]
    """Text not exceeding 1000 characters"""

    trademark_office: Required[str]
    """Text not exceeding 1000 characters"""

    trademark_symbol: Required[str]
    """Text not exceeding 1000 characters"""

    urls: Required[str]
    """A list of valid URLs separated by ‘\n’ (new line character).

    The list of the URLs should not exceed 250 URLs. All URLs should have the same
    hostname. Each URL should be unique. This field may be released by Cloudflare to
    third parties such as the Lumen Database (https://lumendatabase.org/).
    """

    comments: str
    """Any additional comments about the infringement not exceeding 2000 characters"""

    company: str
    """Text not exceeding 100 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    reported_country: str
    """Text containing 2 characters"""

    reported_user_agent: str
    """Text not exceeding 255 characters"""

    tele: str
    """Text not exceeding 20 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    title: str
    """Text not exceeding 255 characters"""


class AbuseReportsGeneralReport(TypedDict, total=False):
    account_id: Required[str]

    act: Required[Literal["abuse_general"]]
    """The report type for submitted reports."""

    email: Required[str]
    """A valid email of the abuse reporter.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    email2: Required[str]
    """Should match the value provided in `email`"""

    host_notification: Required[Literal["send", "send-anon"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    justification: Required[str]
    """
    A detailed description of the infringement, including any necessary access
    details and the exact steps needed to view the content, not exceeding 5000
    characters.
    """

    name: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    owner_notification: Required[Literal["send", "send-anon"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    urls: Required[str]
    """A list of valid URLs separated by ‘\n’ (new line character).

    The list of the URLs should not exceed 250 URLs. All URLs should have the same
    hostname. Each URL should be unique. This field may be released by Cloudflare to
    third parties such as the Lumen Database (https://lumendatabase.org/).
    """

    comments: str
    """Any additional comments about the infringement not exceeding 2000 characters"""

    company: str
    """Text not exceeding 100 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    destination_ips: str
    """A list of IP addresses separated by ‘\n’ (new line character).

    The list of destination IPs should not exceed 30 IP addresses. Each one of the
    IP addresses ought to be unique.
    """

    ports_protocols: str
    """A comma separated list of ports and protocols e.g.

    80/TCP, 22/UDP. The total size of the field should not exceed 2000 characters.
    Each individual port/protocol should not exceed 100 characters. The list should
    not have more than 30 unique ports and protocols.
    """

    reported_country: str
    """Text containing 2 characters"""

    reported_user_agent: str
    """Text not exceeding 255 characters"""

    source_ips: str
    """A list of IP addresses separated by ‘\n’ (new line character).

    The list of source IPs should not exceed 30 IP addresses. Each one of the IP
    addresses ought to be unique.
    """

    tele: str
    """Text not exceeding 20 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    title: str
    """Text not exceeding 255 characters"""


class AbuseReportsPhishingReport(TypedDict, total=False):
    account_id: Required[str]

    act: Required[Literal["abuse_phishing"]]
    """The report type for submitted reports."""

    email: Required[str]
    """A valid email of the abuse reporter.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    email2: Required[str]
    """Should match the value provided in `email`"""

    host_notification: Required[Literal["send", "send-anon"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    justification: Required[str]
    """
    A detailed description of the infringement, including any necessary access
    details and the exact steps needed to view the content, not exceeding 5000
    characters.
    """

    name: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    owner_notification: Required[Literal["send", "send-anon"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    urls: Required[str]
    """A list of valid URLs separated by ‘\n’ (new line character).

    The list of the URLs should not exceed 250 URLs. All URLs should have the same
    hostname. Each URL should be unique. This field may be released by Cloudflare to
    third parties such as the Lumen Database (https://lumendatabase.org/).
    """

    comments: str
    """Any additional comments about the infringement not exceeding 2000 characters"""

    company: str
    """Text not exceeding 100 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    original_work: str
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    reported_country: str
    """Text containing 2 characters"""

    reported_user_agent: str
    """Text not exceeding 255 characters"""

    tele: str
    """Text not exceeding 20 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    title: str
    """Text not exceeding 255 characters"""


class AbuseReportsCsamReport(TypedDict, total=False):
    account_id: Required[str]

    act: Required[Literal["abuse_children"]]
    """The report type for submitted reports."""

    email: Required[str]
    """A valid email of the abuse reporter.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    email2: Required[str]
    """Should match the value provided in `email`"""

    host_notification: Required[Literal["send", "send-anon"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    justification: Required[str]
    """
    A detailed description of the infringement, including any necessary access
    details and the exact steps needed to view the content, not exceeding 5000
    characters.
    """

    name: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    ncmec_notification: Required[Literal["send", "send-anon"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    owner_notification: Required[Literal["send", "send-anon", "none"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    urls: Required[str]
    """A list of valid URLs separated by ‘\n’ (new line character).

    The list of the URLs should not exceed 250 URLs. All URLs should have the same
    hostname. Each URL should be unique. This field may be released by Cloudflare to
    third parties such as the Lumen Database (https://lumendatabase.org/).
    """

    comments: str
    """Any additional comments about the infringement not exceeding 2000 characters"""

    company: str
    """Text not exceeding 100 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    country: str
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    reported_country: str
    """Text containing 2 characters"""

    reported_user_agent: str
    """Text not exceeding 255 characters"""

    tele: str
    """Text not exceeding 20 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    title: str
    """Text not exceeding 255 characters"""


class AbuseReportsThreatReport(TypedDict, total=False):
    account_id: Required[str]

    act: Required[Literal["abuse_threat"]]
    """The report type for submitted reports."""

    email: Required[str]
    """A valid email of the abuse reporter.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    email2: Required[str]
    """Should match the value provided in `email`"""

    host_notification: Required[Literal["send", "send-anon"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    justification: Required[str]
    """
    A detailed description of the infringement, including any necessary access
    details and the exact steps needed to view the content, not exceeding 5000
    characters.
    """

    name: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    owner_notification: Required[Literal["send", "send-anon"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    urls: Required[str]
    """A list of valid URLs separated by ‘\n’ (new line character).

    The list of the URLs should not exceed 250 URLs. All URLs should have the same
    hostname. Each URL should be unique. This field may be released by Cloudflare to
    third parties such as the Lumen Database (https://lumendatabase.org/).
    """

    comments: str
    """Any additional comments about the infringement not exceeding 2000 characters"""

    company: str
    """Text not exceeding 100 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    reported_country: str
    """Text containing 2 characters"""

    reported_user_agent: str
    """Text not exceeding 255 characters"""

    tele: str
    """Text not exceeding 20 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    title: str
    """Text not exceeding 255 characters"""


class AbuseReportsRegistrarWhoisReport(TypedDict, total=False):
    account_id: Required[str]

    act: Required[Literal["abuse_registrar_whois"]]
    """The report type for submitted reports."""

    email: Required[str]
    """A valid email of the abuse reporter.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    email2: Required[str]
    """Should match the value provided in `email`"""

    name: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    owner_notification: Required[Literal["send", "send-anon", "none"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    urls: Required[str]
    """A list of valid URLs separated by ‘\n’ (new line character).

    The list of the URLs should not exceed 250 URLs. All URLs should have the same
    hostname. Each URL should be unique. This field may be released by Cloudflare to
    third parties such as the Lumen Database (https://lumendatabase.org/).
    """

    comments: str
    """Any additional comments about the infringement not exceeding 2000 characters"""

    company: str
    """Text not exceeding 100 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    reg_who_request: AbuseReportsRegistrarWhoisReportRegWhoRequest
    """RDP-mandated fields for registrar WHOIS data disclosure requests."""

    reported_country: str
    """Text containing 2 characters"""

    reported_user_agent: str
    """Text not exceeding 255 characters"""

    tele: str
    """Text not exceeding 20 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    title: str
    """Text not exceeding 255 characters"""


class AbuseReportsRegistrarWhoisReportRegWhoRequest(TypedDict, total=False):
    """RDP-mandated fields for registrar WHOIS data disclosure requests."""

    reg_who_good_faith_affirmation: Required[bool]
    """Affirmation that the request is made in good faith per RDP 10.2.4.

    Must be true.
    """

    reg_who_lawful_processing_agreement: Required[bool]
    """Agreement to process data lawfully per RDP 10.2.5. Must be true."""

    reg_who_legal_basis: Required[str]
    """Legal rights and rationale for the request per RDP 10.2.3.

    Required for all WHOIS requests.
    """

    reg_who_request_type: Required[Literal["disclosure", "invalid_whois"]]
    """The type of WHOIS data request per RDP procedure."""

    reg_who_requested_data_elements: Required[
        List[
            Literal[
                "registrant_name",
                "registrant_organization",
                "registrant_email",
                "registrant_phone",
                "registrant_address",
                "registrant_address_country",
                "registrant_address_postal_code",
                "admin_name",
                "admin_organization",
                "admin_email",
                "admin_phone",
                "admin_address",
                "tech_name",
                "tech_organization",
                "tech_email",
                "tech_phone",
                "tech_address",
            ]
        ]
    ]
    """The specific WHOIS data elements being requested per RDP 10.2.2.

    Required for all WHOIS requests.
    """

    reg_who_authorization_statement: str
    """Optional authorization statement or power of attorney per RDP 10.2.1.3."""

    reg_who_requestor_type: Literal["government", "corporation", "individual"]
    """The nature of the requestor per RDP 10.2.1.2."""


class AbuseReportsNcseiReport(TypedDict, total=False):
    account_id: Required[str]

    act: Required[Literal["abuse_ncsei"]]
    """The report type for submitted reports."""

    email: Required[str]
    """A valid email of the abuse reporter.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    email2: Required[str]
    """Should match the value provided in `email`"""

    host_notification: Required[Literal["send", "send-anon"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    name: Required[str]
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    ncsei_subject_representation: Required[bool]
    """If the submitter is the target of NCSEI in the URLs of the abuse report."""

    owner_notification: Required[Literal["send", "send-anon", "none"]]
    """Notification type based on the abuse type.

    NOTE: Copyright (DMCA) and Trademark reports cannot be anonymous.
    """

    urls: Required[str]
    """A list of valid URLs separated by ‘\n’ (new line character).

    The list of the URLs should not exceed 250 URLs. All URLs should have the same
    hostname. Each URL should be unique. This field may be released by Cloudflare to
    third parties such as the Lumen Database (https://lumendatabase.org/).
    """

    comments: str
    """Any additional comments about the infringement not exceeding 2000 characters"""

    company: str
    """Text not exceeding 100 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    country: str
    """Text not exceeding 255 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    reported_country: str
    """Text containing 2 characters"""

    reported_user_agent: str
    """Text not exceeding 255 characters"""

    tele: str
    """Text not exceeding 20 characters.

    This field may be released by Cloudflare to third parties such as the Lumen
    Database (https://lumendatabase.org/).
    """

    title: str
    """Text not exceeding 255 characters"""


AbuseReportCreateParams: TypeAlias = Union[
    AbuseReportsDmcaReport,
    AbuseReportsTrademarkReport,
    AbuseReportsGeneralReport,
    AbuseReportsPhishingReport,
    AbuseReportsCsamReport,
    AbuseReportsThreatReport,
    AbuseReportsRegistrarWhoisReport,
    AbuseReportsNcseiReport,
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["IssueType"]

IssueType: TypeAlias = Literal[
    "compliance_violation",
    "email_security",
    "exposed_infrastructure",
    "insecure_configuration",
    "weak_authentication",
    "configuration_suggestion",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["BrowserCreateParams"]


class BrowserCreateParams(TypedDict, total=False):
    account_id: Required[str]
    """Account ID."""

    keep_alive: float
    """Keep-alive time in milliseconds."""

    lab: bool
    """Use experimental browser."""

    recording: bool

    targets: bool
    """Include browser targets in response."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["ListListParams"]


class ListListParams(TypedDict, total=False):
    account_id: Required[str]

    type: Literal["SERIAL", "URL", "DOMAIN", "EMAIL", "IP", "CATEGORY", "LOCATION", "DEVICE", "AAGUID"]
    """Specify the list type."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from .projects.projects import (
    ProjectsResource,
    AsyncProjectsResource,
    ProjectsResourceWithRawResponse,
    AsyncProjectsResourceWithRawResponse,
    ProjectsResourceWithStreamingResponse,
    AsyncProjectsResourceWithStreamingResponse,
)

__all__ = ["PagesResource", "AsyncPagesResource"]


class PagesResource(SyncAPIResource):
    @cached_property
    def projects(self) -> ProjectsResource:
        return ProjectsResource(self._client)

    @cached_property
    def with_raw_response(self) -> PagesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return PagesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PagesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return PagesResourceWithStreamingResponse(self)


class AsyncPagesResource(AsyncAPIResource):
    @cached_property
    def projects(self) -> AsyncProjectsResource:
        return AsyncProjectsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPagesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPagesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPagesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncPagesResourceWithStreamingResponse(self)


class PagesResourceWithRawResponse:
    def __init__(self, pages: PagesResource) -> None:
        self._pages = pages

    @cached_property
    def projects(self) -> ProjectsResourceWithRawResponse:
        return ProjectsResourceWithRawResponse(self._pages.projects)


class AsyncPagesResourceWithRawResponse:
    def __init__(self, pages: AsyncPagesResource) -> None:
        self._pages = pages

    @cached_property
    def projects(self) -> AsyncProjectsResourceWithRawResponse:
        return AsyncProjectsResourceWithRawResponse(self._pages.projects)


class PagesResourceWithStreamingResponse:
    def __init__(self, pages: PagesResource) -> None:
        self._pages = pages

    @cached_property
    def projects(self) -> ProjectsResourceWithStreamingResponse:
        return ProjectsResourceWithStreamingResponse(self._pages.projects)


class AsyncPagesResourceWithStreamingResponse:
    def __init__(self, pages: AsyncPagesResource) -> None:
        self._pages = pages

    @cached_property
    def projects(self) -> AsyncProjectsResourceWithStreamingResponse:
        return AsyncProjectsResourceWithStreamingResponse(self._pages.projects)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ...._types import SequenceNotStr

__all__ = ["UnrevokeCreateParams"]


class UnrevokeCreateParams(TypedDict, total=False):
    account_id: Required[str]

    body: Required[SequenceNotStr[str]]
    """A list of Registration IDs to unrevoke."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, cast

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ....pagination import SyncSinglePage, AsyncSinglePage
from ...._base_client import AsyncPaginator, make_request_options
from ....types.api_gateway.operations import (
    label_create_params,
    label_update_params,
    label_bulk_create_params,
    label_bulk_update_params,
)
from ....types.api_gateway.operations.label_create_response import LabelCreateResponse
from ....types.api_gateway.operations.label_delete_response import LabelDeleteResponse
from ....types.api_gateway.operations.label_update_response import LabelUpdateResponse
from ....types.api_gateway.operations.label_bulk_create_response import LabelBulkCreateResponse
from ....types.api_gateway.operations.label_bulk_delete_response import LabelBulkDeleteResponse
from ....types.api_gateway.operations.label_bulk_update_response import LabelBulkUpdateResponse

__all__ = ["LabelsResource", "AsyncLabelsResource"]


class LabelsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LabelsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return LabelsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LabelsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return LabelsResourceWithStreamingResponse(self)

    def create(
        self,
        operation_id: str,
        *,
        zone_id: str,
        managed: SequenceNotStr[str] | Omit = omit,
        user: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LabelCreateResponse:
        """
        Attach label(s) on an operation in endpoint management

        Args:
          zone_id: Identifier.

          operation_id: UUID.

          managed: List of managed label names.

          user: List of user label names.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not operation_id:
            raise ValueError(f"Expected a non-empty value for `operation_id` but received {operation_id!r}")
        return self._post(
            path_template(
                "/zones/{zone_id}/api_gateway/operations/{operation_id}/labels",
                zone_id=zone_id,
                operation_id=operation_id,
            ),
            body=maybe_transform(
                {
                    "managed": managed,
                    "user": user,
                },
                label_create_params.LabelCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[LabelCreateResponse]._unwrapper,
            ),
            cast_to=cast(Type[LabelCreateResponse], ResultWrapper[LabelCreateResponse]),
        )

    def update(
        self,
        operation_id: str,
        *,
        zone_id: str,
        managed: SequenceNotStr[str] | Omit = omit,
        user: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LabelUpdateResponse:
        """
        Replace label(s) on an operation in endpoint management

        Args:
          zone_id: Identifier.

          operation_id: UUID.

          managed: List of managed label names. Omitting this property or passing an empty array
              will result in all managed labels being removed from the operation

          user: List of user label names. Omitting this property or passing an empty array will
              result in all user labels being removed from the operation

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not operation_id:
            raise ValueError(f"Expected a non-empty value for `operation_id` but received {operation_id!r}")
        return self._put(
            path_template(
                "/zones/{zone_id}/api_gateway/operations/{operation_id}/labels",
                zone_id=zone_id,
                operation_id=operation_id,
            ),
            body=maybe_transform(
                {
                    "managed": managed,
                    "user": user,
                },
                label_update_params.LabelUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[LabelUpdateResponse]._unwrapper,
            ),
            cast_to=cast(Type[LabelUpdateResponse], ResultWrapper[LabelUpdateResponse]),
        )

    def delete(
        self,
        operation_id: str,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LabelDeleteResponse:
        """
        Remove label(s) on an operation in endpoint management

        Args:
          zone_id: Identifier.

          operation_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not operation_id:
            raise ValueError(f"Expected a non-empty value for `operation_id` but received {operation_id!r}")
        return self._delete(
            path_template(
                "/zones/{zone_id}/api_gateway/operations/{operation_id}/labels",
                zone_id=zone_id,
                operation_id=operation_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[LabelDeleteResponse]._unwrapper,
            ),
            cast_to=cast(Type[LabelDeleteResponse], ResultWrapper[LabelDeleteResponse]),
        )

    def bulk_create(
        self,
        *,
        zone_id: str,
        selector: label_bulk_create_params.Selector,
        managed: label_bulk_create_params.Managed | Omit = omit,
        user: label_bulk_create_params.User | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[LabelBulkCreateResponse]:
        """
        Bulk attach label(s) on operation(s) in endpoint management

        Args:
          zone_id: Identifier.

          selector: Operation IDs selector

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/api_gateway/operations/labels", zone_id=zone_id),
            page=SyncSinglePage[LabelBulkCreateResponse],
            body=maybe_transform(
                {
                    "selector": selector,
                    "managed": managed,
                    "user": user,
                },
                label_bulk_create_params.LabelBulkCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=LabelBulkCreateResponse,
            method="post",
        )

    def bulk_delete(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[LabelBulkDeleteResponse]:
        """
        Bulk remove label(s) on operation(s) in endpoint management

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/api_gateway/operations/labels", zone_id=zone_id),
            page=SyncSinglePage[LabelBulkDeleteResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=LabelBulkDeleteResponse,
            method="delete",
        )

    def bulk_update(
        self,
        *,
        zone_id: str,
        managed: label_bulk_update_params.Managed,
        selector: label_bulk_update_params.Selector,
        user: label_bulk_update_params.User,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[LabelBulkUpdateResponse]:
        """
        Bulk replace label(s) on operation(s) in endpoint management

        Args:
          zone_id: Identifier.

          managed: Managed labels to replace for all affected operations

          selector: Operation IDs selector

          user: User labels to replace for all affected operations

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/api_gateway/operations/labels", zone_id=zone_id),
            page=SyncSinglePage[LabelBulkUpdateResponse],
            body=maybe_transform(
                {
                    "managed": managed,
                    "selector": selector,
                    "user": user,
                },
                label_bulk_update_params.LabelBulkUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=LabelBulkUpdateResponse,
            method="put",
        )


class AsyncLabelsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLabelsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncLabelsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLabelsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncLabelsResourceWithStreamingResponse(self)

    async def create(
        self,
        operation_id: str,
        *,
        zone_id: str,
        managed: SequenceNotStr[str] | Omit = omit,
        user: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LabelCreateResponse:
        """
        Attach label(s) on an operation in endpoint management

        Args:
          zone_id: Identifier.

          operation_id: UUID.

          managed: List of managed label names.

          user: List of user label names.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not operation_id:
            raise ValueError(f"Expected a non-empty value for `operation_id` but received {operation_id!r}")
        return await self._post(
            path_template(
                "/zones/{zone_id}/api_gateway/operations/{operation_id}/labels",
                zone_id=zone_id,
                operation_id=operation_id,
            ),
            body=await async_maybe_transform(
                {
                    "managed": managed,
                    "user": user,
                },
                label_create_params.LabelCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[LabelCreateResponse]._unwrapper,
            ),
            cast_to=cast(Type[LabelCreateResponse], ResultWrapper[LabelCreateResponse]),
        )

    async def update(
        self,
        operation_id: str,
        *,
        zone_id: str,
        managed: SequenceNotStr[str] | Omit = omit,
        user: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LabelUpdateResponse:
        """
        Replace label(s) on an operation in endpoint management

        Args:
          zone_id: Identifier.

          operation_id: UUID.

          managed: List of managed label names. Omitting this property or passing an empty array
              will result in all managed labels being removed from the operation

          user: List of user label names. Omitting this property or passing an empty array will
              result in all user labels being removed from the operation

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not operation_id:
            raise ValueError(f"Expected a non-empty value for `operation_id` but received {operation_id!r}")
        return await self._put(
            path_template(
                "/zones/{zone_id}/api_gateway/operations/{operation_id}/labels",
                zone_id=zone_id,
                operation_id=operation_id,
            ),
            body=await async_maybe_transform(
                {
                    "managed": managed,
                    "user": user,
                },
                label_update_params.LabelUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[LabelUpdateResponse]._unwrapper,
            ),
            cast_to=cast(Type[LabelUpdateResponse], ResultWrapper[LabelUpdateResponse]),
        )

    async def delete(
        self,
        operation_id: str,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LabelDeleteResponse:
        """
        Remove label(s) on an operation in endpoint management

        Args:
          zone_id: Identifier.

          operation_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        if not operation_id:
            raise ValueError(f"Expected a non-empty value for `operation_id` but received {operation_id!r}")
        return await self._delete(
            path_template(
                "/zones/{zone_id}/api_gateway/operations/{operation_id}/labels",
                zone_id=zone_id,
                operation_id=operation_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[LabelDeleteResponse]._unwrapper,
            ),
            cast_to=cast(Type[LabelDeleteResponse], ResultWrapper[LabelDeleteResponse]),
        )

    def bulk_create(
        self,
        *,
        zone_id: str,
        selector: label_bulk_create_params.Selector,
        managed: label_bulk_create_params.Managed | Omit = omit,
        user: label_bulk_create_params.User | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[LabelBulkCreateResponse, AsyncSinglePage[LabelBulkCreateResponse]]:
        """
        Bulk attach label(s) on operation(s) in endpoint management

        Args:
          zone_id: Identifier.

          selector: Operation IDs selector

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/api_gateway/operations/labels", zone_id=zone_id),
            page=AsyncSinglePage[LabelBulkCreateResponse],
            body=maybe_transform(
                {
                    "selector": selector,
                    "managed": managed,
                    "user": user,
                },
                label_bulk_create_params.LabelBulkCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=LabelBulkCreateResponse,
            method="post",
        )

    def bulk_delete(
        self,
        *,
        zone_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[LabelBulkDeleteResponse, AsyncSinglePage[LabelBulkDeleteResponse]]:
        """
        Bulk remove label(s) on operation(s) in endpoint management

        Args:
          zone_id: Identifier.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/api_gateway/operations/labels", zone_id=zone_id),
            page=AsyncSinglePage[LabelBulkDeleteResponse],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=LabelBulkDeleteResponse,
            method="delete",
        )

    def bulk_update(
        self,
        *,
        zone_id: str,
        managed: label_bulk_update_params.Managed,
        selector: label_bulk_update_params.Selector,
        user: label_bulk_update_params.User,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[LabelBulkUpdateResponse, AsyncSinglePage[LabelBulkUpdateResponse]]:
        """
        Bulk replace label(s) on operation(s) in endpoint management

        Args:
          zone_id: Identifier.

          managed: Managed labels to replace for all affected operations

          selector: Operation IDs selector

          user: User labels to replace for all affected operations

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zone_id:
            raise ValueError(f"Expected a non-empty value for `zone_id` but received {zone_id!r}")
        return self._get_api_list(
            path_template("/zones/{zone_id}/api_gateway/operations/labels", zone_id=zone_id),
            page=AsyncSinglePage[LabelBulkUpdateResponse],
            body=maybe_transform(
                {
                    "managed": managed,
                    "selector": selector,
                    "user": user,
                },
                label_bulk_update_params.LabelBulkUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=LabelBulkUpdateResponse,
            method="put",
        )


class LabelsResourceWithRawResponse:
    def __init__(self, labels: LabelsResource) -> None:
        self._labels = labels

        self.create = to_raw_response_wrapper(
            labels.create,
        )
        self.update = to_raw_response_wrapper(
            labels.update,
        )
        self.delete = to_raw_response_wrapper(
            labels.delete,
        )
        self.bulk_create = to_raw_response_wrapper(
            labels.bulk_create,
        )
        self.bulk_delete = to_raw_response_wrapper(
            labels.bulk_delete,
        )
        self.bulk_update = to_raw_response_wrapper(
            labels.bulk_update,
        )


class AsyncLabelsResourceWithRawResponse:
    def __init__(self, labels: AsyncLabelsResource) -> None:
        self._labels = labels

        self.create = async_to_raw_response_wrapper(
            labels.create,
        )
        self.update = async_to_raw_response_wrapper(
            labels.update,
        )
        self.delete = async_to_raw_response_wrapper(
            labels.delete,
        )
        self.bulk_create = async_to_raw_response_wrapper(
            labels.bulk_create,
        )
        self.bulk_delete = async_to_raw_response_wrapper(
            labels.bulk_delete,
        )
        self.bulk_update = async_to_raw_response_wrapper(
            labels.bulk_update,
        )


class LabelsResourceWithStreamingResponse:
    def __init__(self, labels: LabelsResource) -> None:
        self._labels = labels

        self.create = to_streamed_response_wrapper(
            labels.create,
        )
        self.update = to_streamed_response_wrapper(
            labels.update,
        )
        self.delete = to_streamed_response_wrapper(
            labels.delete,
        )
        self.bulk_create = to_streamed_response_wrapper(
            labels.bulk_create,
        )
        self.bulk_delete = to_streamed_response_wrapper(
            labels.bulk_delete,
        )
        self.bulk_update = to_streamed_response_wrapper(
            labels.bulk_update,
        )


class AsyncLabelsResourceWithStreamingResponse:
    def __init__(self, labels: AsyncLabelsResource) -> None:
        self._labels = labels

        self.create = async_to_streamed_response_wrapper(
            labels.create,
        )
        self.update = async_to_streamed_response_wrapper(
            labels.update,
        )
        self.delete = async_to_streamed_response_wrapper(
            labels.delete,
        )
        self.bulk_create = async_to_streamed_response_wrapper(
            labels.bulk_create,
        )
        self.bulk_delete = async_to_streamed_response_wrapper(
            labels.bulk_delete,
        )
        self.bulk_update = async_to_streamed_response_wrapper(
            labels.bulk_update,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ...._models import BaseModel

__all__ = ["DevicePolicyCertificates"]


class DevicePolicyCertificates(BaseModel):
    enabled: bool
    """
    The current status of the device policy certificate provisioning feature for
    WARP clients.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["ReclassifyCreateParams"]


class ReclassifyCreateParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier."""

    expected_disposition: Required[Literal["NONE", "BULK", "MALICIOUS", "SPAM", "SPOOF", "SUSPICIOUS"]]

    eml_content: str
    """Base64 encoded content of the EML file."""

    escalated_submission_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["WebhookGetResponse"]


class WebhookGetResponse(BaseModel):
    modified: Optional[datetime] = None
    """The date and time the webhook was last modified."""

    notification_url: Optional[str] = FieldInfo(alias="notificationUrl", default=None)
    """The URL where webhooks will be sent."""

    secret: Optional[str] = None
    """The secret used to verify webhook signatures."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel
from ..digital_experience_monitor import DigitalExperienceMonitor
from .http_tests.test_stat_over_time import TestStatOverTime

__all__ = [
    "HTTPDetails",
    "HTTPStats",
    "HTTPStatsAvailabilityPct",
    "HTTPStatsAvailabilityPctSlot",
    "HTTPStatsHTTPStatusCode",
    "HTTPStatsByColo",
    "HTTPStatsByColoAvailabilityPct",
    "HTTPStatsByColoAvailabilityPctSlot",
    "HTTPStatsByColoHTTPStatusCode",
]


class HTTPStatsAvailabilityPctSlot(BaseModel):
    timestamp: str

    value: float


class HTTPStatsAvailabilityPct(BaseModel):
    slots: List[HTTPStatsAvailabilityPctSlot]

    avg: Optional[float] = None
    """average observed in the time period"""

    max: Optional[float] = None
    """highest observed in the time period"""

    min: Optional[float] = None
    """lowest observed in the time period"""


class HTTPStatsHTTPStatusCode(BaseModel):
    status200: int

    status300: int

    status400: int

    status500: int

    timestamp: str


class HTTPStats(BaseModel):
    availability_pct: HTTPStatsAvailabilityPct = FieldInfo(alias="availabilityPct")

    dns_response_time_ms: TestStatOverTime = FieldInfo(alias="dnsResponseTimeMs")

    http_status_code: List[HTTPStatsHTTPStatusCode] = FieldInfo(alias="httpStatusCode")

    resource_fetch_time_ms: TestStatOverTime = FieldInfo(alias="resourceFetchTimeMs")

    server_response_time_ms: TestStatOverTime = FieldInfo(alias="serverResponseTimeMs")

    unique_devices_total: int = FieldInfo(alias="uniqueDevicesTotal")
    """Count of unique devices that have run this test in the given time period"""


class HTTPStatsByColoAvailabilityPctSlot(BaseModel):
    timestamp: str

    value: float


class HTTPStatsByColoAvailabilityPct(BaseModel):
    slots: List[HTTPStatsByColoAvailabilityPctSlot]

    avg: Optional[float] = None
    """average observed in the time period"""

    max: Optional[float] = None
    """highest observed in the time period"""

    min: Optional[float] = None
    """lowest observed in the time period"""


class HTTPStatsByColoHTTPStatusCode(BaseModel):
    status200: int

    status300: int

    status400: int

    status500: int

    timestamp: str


class HTTPStatsByColo(BaseModel):
    availability_pct: HTTPStatsByColoAvailabilityPct = FieldInfo(alias="availabilityPct")

    colo: str

    dns_response_time_ms: TestStatOverTime = FieldInfo(alias="dnsResponseTimeMs")

    http_status_code: List[HTTPStatsByColoHTTPStatusCode] = FieldInfo(alias="httpStatusCode")

    resource_fetch_time_ms: TestStatOverTime = FieldInfo(alias="resourceFetchTimeMs")

    server_response_time_ms: TestStatOverTime = FieldInfo(alias="serverResponseTimeMs")

    unique_devices_total: int = FieldInfo(alias="uniqueDevicesTotal")
    """Count of unique devices that have run this test in the given time period"""


class HTTPDetails(BaseModel):
    host: Optional[str] = None
    """The url of the HTTP synthetic application test"""

    http_stats: Optional[HTTPStats] = FieldInfo(alias="httpStats", default=None)

    http_stats_by_colo: Optional[List[HTTPStatsByColo]] = FieldInfo(alias="httpStatsByColo", default=None)

    interval: Optional[str] = None
    """The interval at which the HTTP synthetic application test is set to run."""

    kind: Optional[Literal["http"]] = None

    method: Optional[str] = None
    """The HTTP method to use when running the test"""

    name: Optional[str] = None
    """The name of the HTTP synthetic application test"""

    target_policies: Optional[List[DigitalExperienceMonitor]] = None

    targeted: Optional[bool] = None
